@@ -1307,13 +1307,13 @@ class CodeGenerator(NodeVisitor):
             def finalize(value):
                 return default(env_finalize(value))
 
-            if getattr(env_finalize, "contextfunction", False):
+            if getattr(env_finalize, "contextfunction", False) is True:
                 src += "context, "
                 finalize = None  # noqa: F811
-            elif getattr(env_finalize, "evalcontextfunction", False):
+            elif getattr(env_finalize, "evalcontextfunction", False) is True:
                 src += "context.eval_ctx, "
                 finalize = None
-            elif getattr(env_finalize, "environmentfunction", False):
+            elif getattr(env_finalize, "environmentfunction", False) is True:
                 src += "environment, "
 
                 def finalize(value):
@@ -1641,14 +1641,14 @@ class CodeGenerator(NodeVisitor):
     @optimizeconst
     def visit_Getattr(self, node, frame):
         if self.environment.is_async:
-            self.write("await auto_await(")
+            self.write("(await auto_await(")
 
         self.write("environment.getattr(")
         self.visit(node.node, frame)
         self.write(", %r)" % node.attr)
 
         if self.environment.is_async:
-            self.write(")")
+            self.write("))")
 
     @optimizeconst
     def visit_Getitem(self, node, frame):
@@ -1660,7 +1660,7 @@ class CodeGenerator(NodeVisitor):
             self.write("]")
         else:
             if self.environment.is_async:
-                self.write("await auto_await(")
+                self.write("(await auto_await(")
 
             self.write("environment.getitem(")
             self.visit(node.node, frame)
@@ -1669,7 +1669,7 @@ class CodeGenerator(NodeVisitor):
             self.write(")")
 
             if self.environment.is_async:
-                self.write(")")
+                self.write("))")
 
     def visit_Slice(self, node, frame):
         if node.start is not None:
@@ -1689,11 +1689,11 @@ class CodeGenerator(NodeVisitor):
         func = self.environment.filters.get(node.name)
         if func is None:
             self.fail("no filter named %r" % node.name, node.lineno)
-        if getattr(func, "contextfilter", False):
+        if getattr(func, "contextfilter", False) is True:
             self.write("context, ")
-        elif getattr(func, "evalcontextfilter", False):
+        elif getattr(func, "evalcontextfilter", False) is True:
             self.write("context.eval_ctx, ")
-        elif getattr(func, "environmentfilter", False):
+        elif getattr(func, "environmentfilter", False) is True:
             self.write("environment, ")
 
         # if the filter node is None we are inside a filter block
